@@ -15,7 +15,7 @@ def get_sql(*args):
 def get_result(*args):
     try:
         rid = int(sys.argv[1])
-        print api.get_result_csv(qid)
+        print api.get_result_csv(rid)
     except ValueError:
         print "Not a valid integer for result id"
 
